@@ -1,7 +1,6 @@
 import sys
 import datetime
 from urllib.parse import urlparse
-
 from .exceptions import ParamError
 
 
@@ -119,9 +118,11 @@ def is_legal_index_size(index_size):
 def is_legal_table_name(table_name):
     return isinstance(table_name, str) and len(table_name) > 0
 
+
 def is_legal_field_name(field_name):
     return isinstance(field_name, str) and len(field_name) > 0
 
+
 def is_legal_nlist(nlist):
     return not isinstance(nlist, bool) and isinstance(nlist, int)
 
@@ -199,6 +200,36 @@ def is_legal_partition_tag_array(tag_array):
     return True
 
 
+# https://milvus.io/cn/docs/v1.0.0/metric.md#floating
+def is_legal_index_metric_type(index_type: str, metric_type: str) -> bool:
+    if index_type not in ["FLAT",
+                          "IVF_FLAT",
+                          "IVF_SQ8",
+                          # "IVF_SQ8_HYBRID",
+                          "IVF_PQ",
+                          "HNSW",
+                          # "NSG",
+                          "ANNOY",
+                          "RHNSW_FLAT",
+                          "RHNSW_PQ",
+                          "RHNSW_SQ", ]:
+        return False
+    if metric_type not in ["L2", "IP"]:
+        return False
+    return True
+
+
+# https://milvus.io/cn/docs/v1.0.0/metric.md#binary
+def is_legal_binary_index_metric_type(index_type: str, metric_type: str) -> bool:
+    if index_type == "BIN_FLAT":
+        if metric_type in ["JACCARD", "TANIMOTO", "HAMMING", "SUBSTRUCTURE", "SUPERSTRUCTURE"]:
+            return True
+    elif index_type == "BIN_IVF_FLAT":
+        if metric_type in ["JACCARD", "TANIMOTO", "HAMMING"]:
+            return True
+    return False
+
+
 def _raise_param_error(param_name, param_value):
     raise ParamError("`{}` value {} is illegal".format(param_name, param_value))
 
