@@ -13,7 +13,7 @@ from ..grpc_gen import milvus_pb2_grpc
 from ..grpc_gen import milvus_pb2 as milvus_types
 from .abstract import QueryResult, CollectionSchema
 from .prepare import Prepare
-from .types import Status
+from .types import Status, IndexState, SegmentState
 from .check import (
     int_or_str,
     is_legal_host,
@@ -386,7 +386,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler([])
     def list_collections(self, timeout=30):
-        request = Prepare.show_collection_request()
+        request = Prepare.show_collections_request()
         rf = self._stub.ShowCollections.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         status = response.status
@@ -444,7 +444,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler([])
     def list_partitions(self, collection_name, timeout=30):
-        request = Prepare.show_partition_request(collection_name)
+        request = Prepare.show_partitions_request(collection_name)
 
         rf = self._stub.ShowPartitions.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
@@ -609,7 +609,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler(None)
     def get_query_segment_infos(self, collection_name, timeout=30, **kwargs):
-        req = milvus_types.QuerySegmentInfoRequest(collectionName=collection_name)
+        req = Prepare.get_query_segment_info_request(collection_name)
         future = self._stub.GetQuerySegmentInfo.future(req, wait_for_ready=True, timeout=timeout)
         response = future.result()
         status = response.status
@@ -697,7 +697,7 @@ class GrpcHandler(AbsMilvus):
             return None
         raise BaseException(status.error_code, status.reason)
 
-    @error_handler(common_types.IndexState.INDEX_STATE_FAILED)
+    @error_handler(IndexState.Failed)
     def get_index_state(self, collection_name, field_name, timeout=None, **kwargs):
         request = Prepare.get_index_state_request(collection_name, field_name)
         rf = self._stub.GetIndexState.future(request, wait_for_ready=True, timeout=timeout)
@@ -714,9 +714,9 @@ class GrpcHandler(AbsMilvus):
             print("\n***********  waiting for building index ***********\n")
             try:
                 state = self.get_index_state(collection_name, field_name, timeout, **kwargs)
-                if state == common_types.IndexState.INDEX_STATE_FINISHED:
+                if state == IndexState.Finished:
                     return True
-                if state == common_types.IndexState.INDEX_STATE_FAILED:
+                if state == IndexState.Failed:
                     return False
             except BaseException:
                 return False
@@ -790,7 +790,7 @@ class GrpcHandler(AbsMilvus):
         """
         Block until load partition complete.
         """
-        request = Prepare.show_partition_request(collection_name)
+        request = Prepare.show_partitions_request(collection_name)
         rf = self._stub.ShowPartitions.future(request, wait_for_ready=True, timeout=timeout)
         response = rf.result()
         status = response.status
@@ -834,7 +834,7 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler(None)
     def get_persistent_segment_infos(self, collection_name, timeout=30, **kwargs):
-        req = milvus_types.PersistentSegmentInfoRequest(collectionName=collection_name)
+        req = Prepare.get_persistent_segment_info_request(collection_name)
         future = self._stub.GetPersistentSegmentInfo.future(req, wait_for_ready=True, timeout=timeout)
         response = future.result()
         status = response.status
@@ -849,7 +849,7 @@ class GrpcHandler(AbsMilvus):
                 infos = self.get_persistent_segment_infos(collection_name, timeout, **kwargs)
                 for info in infos:
                     print("info.state: ", info.state)
-                    if info.state != common_types.SegmentState.SegmentFlushed:
+                    if info.state != SegmentState.Flushed:
                         return False
                 return True
             except BaseException:
@@ -899,6 +899,6 @@ class GrpcHandler(AbsMilvus):
 
     @error_handler(False)
     def fake_register_link(self, timeout=30):
-        request = Prepare.empty()
+        request = Prepare.register_link_request()
         future = self._stub.RegisterLink.future(request, wait_for_ready=True, timeout=timeout)
         return future.result().status.error_code == 0
