@@ -14,7 +14,7 @@ from ..grpc_gen import milvus_pb2 as milvus_types
 
 from . import blob
 
-from .types import RangeType, DataType, MetricType, IndexType
+from .types import RangeType, DataType, MetricType, IndexType, PlaceholderType
 
 
 class Prepare:
@@ -127,8 +127,8 @@ class Prepare:
         return milvus_types.CollectionStatsRequest(collection_name=collection_name)
 
     @classmethod
-    def show_collection_request(cls):
-        return milvus_types.ShowCollectionRequest()
+    def show_collections_request(cls):
+        return milvus_types.ShowCollectionsRequest()
 
     @classmethod
     def create_partition_request(cls, collection_name, partition_name):
@@ -147,12 +147,17 @@ class Prepare:
         return milvus_types.PartitionStatsRequest(collection_name=collection_name, partition_name=partition_name)
 
     @classmethod
-    def show_partition_request(cls, collection_name):
-        return milvus_types.ShowPartitionRequest(collection_name=collection_name)
+    def show_partitions_request(cls, collection_name):
+        return milvus_types.ShowPartitionsRequest(collection_name=collection_name)
 
     @classmethod
     def empty(cls):
-        return common_types.Empty()
+        raise DeprecationWarning("no empty request later")
+        # return common_types.Empty()
+
+    @classmethod
+    def register_link_request(cls):
+        return milvus_types.RegisterLinkRequest()
 
     @classmethod
     def partition_name(cls, collection_name, partition_tag):
@@ -480,11 +485,11 @@ class Prepare:
             pl = milvus_types.PlaceholderValue(tag=tag)
 
             if isinstance(vectors[0], bytes):
-                pl.type = milvus_types.PlaceholderType.VECTOR_BINARY
+                pl.type = PlaceholderType.BinaryVector
                 for vector in vectors:
                     pl.values.append(blob.vectorBinaryToBytes(vector))
             else:
-                pl.type = milvus_types.PlaceholderType.VECTOR_FLOAT
+                pl.type = PlaceholderType.FloatVector
                 for vector in vectors:
                     pl.values.append(blob.vectorFloatToBytes(vector))
             # vector_values_bytes = service_msg_types.VectorValues.SerializeToString(vector_values)
@@ -528,7 +533,7 @@ class Prepare:
 
     @classmethod
     def get_index_state_request(cls, collection_name, field_name):
-        return milvus_types.IndexStateRequest(collection_name=collection_name, field_name=field_name)
+        return milvus_types.GetIndexStateRequest(collection_name=collection_name, field_name=field_name)
 
     @classmethod
     def load_collection(cls, db_name, collection_name):
@@ -540,17 +545,25 @@ class Prepare:
 
     @classmethod
     def load_partitions(cls, db_name, collection_name, partition_names):
-        return milvus_types.LoadPartitonRequest(db_name=db_name, collection_name=collection_name,
-                                                partition_names=partition_names)
+        return milvus_types.LoadPartitionsRequest(db_name=db_name, collection_name=collection_name,
+                                                  partition_names=partition_names)
 
     @classmethod
     def release_partitions(cls, db_name, collection_name, partition_names):
-        return milvus_types.ReleasePartitionRequest(db_name=db_name, collection_name=collection_name,
+        return milvus_types.ReleasePartitionsRequest(db_name=db_name, collection_name=collection_name,
                                                     partition_names=partition_names)
 
     @classmethod
     def get_collection_stats_request(cls, collection_name):
-        return milvus_types.CollectionStatsRequest(collection_name=collection_name)
+        return milvus_types.GetCollectionStatisticsRequest(collection_name=collection_name)
+
+    @classmethod
+    def get_persistent_segment_info_request(cls, collection_name):
+        return milvus_types.GetPersistentSegmentInfoRequest(collectionName=collection_name)
+
+    @classmethod
+    def get_query_segment_info_request(cls, collection_name):
+        return milvus_types.GetQuerySegmentInfoRequest(collectionName=collection_name)
 
     @classmethod
     def flush_param(cls, collection_names):
