@@ -3,6 +3,7 @@
 import collections
 import functools
 import logging
+import time
 
 from urllib.parse import urlparse
 
@@ -17,6 +18,7 @@ from .utils import valid_binary_metric_types
 from .utils import valid_index_types
 from .utils import valid_binary_index_types
 from .utils import valid_index_params_keys
+from .utils import check_invalid_binary_vector
 
 LOGGER = logging.getLogger(__name__)
 
@@ -115,6 +117,7 @@ class Milvus:
                 except:
                     pass
                 finally:
+                    time.sleep(1)
                     retry -= 1
             raise Exception("server is not healthy, please try again later")
 
@@ -786,6 +789,10 @@ class Milvus:
             ParamError: If parameters are invalid
             BaseException: If the return result from server is not ok
         """
+        # filter invalid binary data #1352: https://github.com/zilliztech/milvus-distributed/issues/1352
+        if not check_invalid_binary_vector(entities):
+            raise ParamError("Invalid binary vector data exists")
+
         if kwargs.get("insert_param", None) is not None:
             with self._connection() as handler:
                 return handler.bulk_insert(None, None, timeout=timeout, **kwargs)
