@@ -113,7 +113,7 @@ class TestInsertBase:
         assert len(ids) == default_nb
         connect.flush([collection])
         connect.create_index(collection, field_name, get_simple_index)
-        info = connect.get_collection_info(collection)
+        info = connect.describe_collection(collection)
         fields = info["fields"]
         for field in fields:
             if field["name"] == field_name:
@@ -130,7 +130,7 @@ class TestInsertBase:
         connect.create_index(collection, field_name, get_simple_index)
         ids = connect.insert(collection, default_entities_rows)
         assert len(ids) == default_nb
-        info = connect.get_collection_info(collection)
+        info = connect.describe_collection(collection)
         fields = info["fields"]
         for field in fields:
             if field["name"] == field_name:
@@ -324,7 +324,7 @@ class TestInsertBinary:
         ids = connect.insert(binary_collection, default_binary_entities_rows)
         assert len(ids) == default_nb
         connect.flush([binary_collection])
-        info = connect.get_collection_info(binary_collection)
+        info = connect.describe_collection(binary_collection)
         fields = info["fields"]
         for field in fields:
             if field["name"] == binary_field_name:
@@ -342,7 +342,7 @@ class TestInsertBinary:
         assert len(ids) == default_nb
         connect.flush([binary_collection])
         connect.create_index(binary_collection, binary_field_name, get_binary_index)
-        info = connect.get_collection_info(binary_collection)
+        info = connect.describe_collection(binary_collection)
         fields = info["fields"]
         for field in fields:
             if field["name"] == binary_field_name:
